# Readme

This script generates example truth and prediction segments
for diarization and identification tasks
and computes reference metrics using [pyannote-metrics](https://github.com/pyannote/pyannote-metrics).

The results are stored in this directory,
to prevent dependency issues with this package.

```bash
uv run error_rates_reference.py
```
